#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
"""
from SLiCAP import *

# Create a list with circuit file names if you want to run multiple circuits.
fileName = 'noiseBudgetsReceiver'
specFileName = "specifications.csv"

# Print show-stopper values for noise sources on HTML page
def showStopperValues2html(i1, noiseResult, specs):
    head2html("Numeric determination of show-stopper values")
    f_min = i1.getParValue('f_min')
    f_max = i1.getParValue('f_max')
    v_on  = i1.getParValue('v_on')
    for src in list(noiseResult.onoiseTerms.keys()):
        head3html(src)
        variable = list((fullSubs(i1.circuit.elements[src].params['noise'], i1.parDefs)).atoms(sp.Symbol))
        if len(variable) != 0:
            variable = variable[0]
        spcContrib  = noiseResult.onoiseTerms[src]
        rmsContrib  = rmsNoise(noiseResult, 'onoise', f_min, f_max, source=src)
        try:
            showStopper = sp.factor(sp.solve(rmsContrib - v_on, variable)[0])
        except IndexError:
            showStopper = None
        if showStopper != None:
            text2html("Spectral contribution of %s:."%(src))
            unit = src[0]
            if unit == "I":
                unit = "A"
            unit += "^2/Hz"
            eqn2html("S_" + src, spcContrib, unit)
            text2html("Show stopper value for noise contribution of %s:."%(src))
            if str(variable)[0].upper() == "R":
                unit = "Omega"
            eqn2html(variable, showStopper, unit)
            if i1.simType == "numeric":
                specs.append(
                    specItem(
                        str(variable) + "_max",
                        description = "Show-stopper value for noise contribution of %s."%(src),
                        value    = showStopper,
                        units       = unit,
                        specType    = "design",
                    )
                )
        else:
            unit = i1.detUnits
            text2html("RMS output noise voltage caused by %s:."%(src))
            eqn2html('RMS_' + src, rmsContrib, unit)
            try:
                if rmsContrib > i1.getParValue("v_on"):
                    text2html("FOUND SHOW-STOPPER: increase transmitter drive level!")
            except TypeError:
                pass
    return (i1, noiseResult, specs)

# Define an instruction
i1 = instruction()
i1.setCircuit(fileName + '.cir')

# import the specifications
specs = csv2specs(specFileName)

# Define the circuit parameters from the specifications
specs2circuit(specs, i1)

i1.setGainType('vi')
i1.setDataType('noise')
# Define the detector for determination of the detector-referred noise
i1.setDetector('V_out')
i1.setSimType('numeric')

i1.defPar("C_r",0) # Symbolic noise integration become too complex with C_r
noiseResult = i1.execute()

htmlPage("Determination of show-stopper values of noise sources")
head2html("Circuit diagram")
img2html(fileName + '.svg', 700)

noiseResult = i1.execute()
i1, noiseResult, specs = showStopperValues2html(i1, noiseResult, specs)

# Save the specifications and display the specifications on a html page.
htmlPage("Updated specifications")
# Save the specifications
specs2csv(specs, "specifications.csv")
# Display them on an HTML page
specs2html(specs)
